<?php

class AuthController extends Service_Controller_Action {
	
    public function init() {
        // Load Settings
		$oServiceSetting = new Service_Setting();
		$this->view->aSettings = $oServiceSetting->getSettings();
    }

    public function indexAction() {
        // action body
    }
	
	public function createAction() {
		$this->_helper->layout()->setLayout('login');
		
		// check permissions
		$oServiceSetting = new Service_Setting();
		$aSettings = $oServiceSetting->getSettings();
		
		if (false == $aSettings['user_registration'])
		{
			$this->_redirect('/');
		}
		
		$oForm = new Application_Form_Auth_Create();
		
        if ($this->getRequest()->isPost()) {
            $aFormData = $this->getRequest()->getPost();
			
            if ($oForm->isValid($aFormData)) {
            	$oServiceUser = new Service_User();
				
				// Check if email already exists.
				if (!is_null($oServiceUser->getUserByMail($aFormData['email'])))
				{
					$this->_helper->flashMessenger->setNamespace('error')->addMessage('This e-mail address already exists.');
					$this->_redirect('/auth/create');
				}
				
				// Create new disabled account.
				$iUserId = $oServiceUser->newUser($aFormData, (true == $aSettings['user_auto_approve']) ? true : false);
				
				if (true == $aSettings['user_auto_approve'])
				{
					$this->_helper->flashMessenger->setNamespace('success')->addMessage('Your account created successfully. You can now login.');
				}
				else 
				{
					$this->_helper->flashMessenger->setNamespace('success')->addMessage('Your account created successfully. Please wait for your application to be reviewed by administrator.');
				}
				
				// send mail to admin.
				$oServiceMail = new Service_Mail();
				$oServiceMail->newUserMail($iUserId);
				
				$this->_redirect('/auth/login');
			}
		}
		
		$this->view->form = $oForm;
	}
	
    public function loginAction() {
    	$this->_helper->layout()->setLayout('login');
		
        // already logged in?
        if (Zend_Auth::getInstance()->hasIdentity()) {
            $this->_redirect('/');
        }

        $oForm = new Application_Form_Auth_Login();
        $this->view->form = $oForm;
		
		// check if url-email-param exist
		if (isset($_GET['mail']) && strlen($_GET['mail']) > 0)
		{
			$oForm->setDefault('email',  $_GET['mail']);
		}
		
        if ($this->getRequest()->isPost()) {
            $formData = $this->getRequest()->getPost();
			
            if ($oForm->isValid($formData)) {
                $authAdapter = $this->getAuthAdapter();
                $authAdapter->setIdentity($oForm->getValue('email'));
                $authAdapter->setCredential($oForm->getValue('password'));

                $auth = Zend_Auth::getInstance();
                $res = $auth->authenticate($authAdapter);

                if ($res->isValid()) {
                    $identity = $authAdapter->getResultRowObject();
					//var_dump($identity); die;
					if ($identity->active == Service_User::USER_STATE_ACTIVE) {
	                    $authStorage = $auth->getStorage();
	                    $authStorage->write($identity);
						
						$usersNs = new Zend_Session_NameSpace("members");
						$usersNs->userType = $identity->privilege;

						$this->_redirect('/');
					} else {
						$this->_helper->flashMessenger->setNamespace('error')->addMessage('Your account is disabled.');		
					}
                }
				
				Zend_Auth::getInstance()->clearIdentity();
				$this->_helper->flashMessenger->setNamespace('error')->addMessage('Sign in attempt failed. Please check your email address and password.');
				$this->_redirect('/');
            } else {
                $oForm->populate($formData);
				//$this->_redirect('/auth/login?mail=' . $formData['email']);
            }
        }

		$this->render();
    }

	public function passwordAction() {
		$oForm = new Application_Form_Auth_Password();
        $this->view->form = $oForm;
		
		// check if url-email-param exist
		if (isset($_GET['mail']) && strlen($_GET['mail']) > 0)
		{
			$oForm->setDefault('email',  $_GET['mail']);
		}
		
        if ($this->getRequest()->isPost()) {
            $aFormData = $this->getRequest()->getPost();
            if ($oForm->isValid($aFormData)) {
            	$oServiceMail = new Service_Mail();
				$oServiceMail->sendPasswordMail($aFormData['email']);
				
				$this->_helper->flashMessenger->setNamespace('success')->addMessage('Your password has been changed. Please check your email.');
				$this->_redirect('/');
			}
		}
		
		$this->_helper->layout()->setLayout('login');
		$this->render();
	}

    public function logoutAction() {
        // action body
        Zend_Auth::getInstance()->clearIdentity();
        $this->_redirect('/');
    }
	
	public function getgravatarhashAction() {
		$this->_helper->layout->disableLayout();
		$this->_helper->viewRenderer->setNoRender(true);
		echo Service_User::getGravatarHash($this->_getParam('email')); 
	}

    /**
     * Liefert den AuthAdapter
     *
     * @return Zend_Auth_Adapter_DbTable
     */
    private function getAuthAdapter() {
        return new Zend_Auth_Adapter_DbTable(
            Zend_Db_Table::getDefaultAdapter(),
            'user',
            'email',
            'password',
            'MD5(?)'
        );
    }
}