<?php

class UserController extends Service_Controller_Action 
{
    protected $_oServiceUser;
	
    public function init() 
    {
    	parent::init();
		
		if ($this->_sPrivilege != Service_User::PRIVILEGE_ADMIN)
		{
			$this->_redirect('/');
		}
		
		$this->_oServiceUser = new Service_User();
    }
	
	public function indexAction() 
	{
		$oAllUser = $this->_oServiceUser->getAll();
		
		$this->view->oAllUser = $oAllUser;
	}
	
	public function changestateAction()
	{
		// disable layout and view
	    $this->view->layout()->disableLayout();
	    $this->_helper->viewRenderer->setNoRender(true);
		
		if (!$this->_hasParam('id'))
		{
			$this->_helper->flashMessenger->setNamespace('error')->addMessage('An error occurred.');
			$this->_redirect('/user');
		}
		
		$oUser = $this->_oServiceUser->getUser($this->_getParam('id'));
		
		if ($oUser)
		{
			if ($oUser->privilege != Service_User::PRIVILEGE_ADMIN)
			{
				$aData = array(
					'active' => ($oUser->active == Service_User::USER_STATE_ACTIVE) ? Service_User::USER_STATE_INACTIVE : Service_User::USER_STATE_ACTIVE
				);
				$this->_oServiceUser->updateUser($aData, $oUser->user_id, false);
			
				$this->_helper->flashMessenger->setNamespace('success')->addMessage('User state updated successfully.');
			}
			else
			{
				$this->_helper->flashMessenger->setNamespace('error')->addMessage('This is not possible with admins.');
			}
		}
		
		$this->_redirect('/user');
	}

	public function deleteAction()
	{
		// disable layout and view
	    $this->view->layout()->disableLayout();
	    $this->_helper->viewRenderer->setNoRender(true);
		
		if (!$this->_hasParam('id'))
		{
			$this->_redirect('/user');
		}
		
		$oUser = $this->_oServiceUser->getUser($this->_getParam('id'));
		
		if (!is_null($oUser))
		{
			$this->_oServiceUser->deleteUser($oUser->user_id);
		}
		
		$this->_helper->flashMessenger->setNamespace('success')->addMessage('User successfull deleted.');
		$this->_redirect('/user');
	}
	
	public function editAction()
	{
		$oForm = new Application_Form_User();
		$oUser = $this->_oServiceUser->getUser($this->_getParam('id'));
		
		$aUser = $oUser->toArray();
		unset($aUser['password']);
		$oForm->setDefaults($aUser);
		
		if ($this->getRequest()->isPost()) 
		{
            $aFormData = $this->getRequest()->getPost();
            if ($oForm->isValid($aFormData)) 
            {
            	/*if ($oUser->user_id == 1 || $oUser->user_id == 2 || $oUser->user_id == 3) {
            		$this->_helper->flashMessenger->setNamespace('error')->addMessage('This is not possible in the demo.');
				} else {*/
					$this->_oServiceUser->updateUser($aFormData, $oUser->user_id, false);
				//}
				
				$this->_helper->flashMessenger->setNamespace('success')->addMessage('User updated successfully.');
				$this->_redirect('/user');
			}
		}
		
		$this->view->oForm = $oForm;
	}
	
	public function newAction()
	{
		$oForm = new Application_Form_User();
		
		if ($this->getRequest()->isPost()) 
		{
            $aFormData = $this->getRequest()->getPost();
            if ($oForm->isValid($aFormData)) 
            {
            	$this->_oServiceUser->newUser($aFormData);
				
				$this->_helper->flashMessenger->setNamespace('success')->addMessage('User created successfully.');
				$this->_redirect('/user');
			}
		}
		
		$this->view->oForm = $oForm;
	}
	
	public function statsAction() 
	{
		$oServiceFile = new Service_File();
		
		$iDiskFreeSpace = disk_free_space(APPLICATION_UPLOADS_DIR . '/');
		$sDiskFreeSpace = $oServiceFile->getFileSize($iDiskFreeSpace);
		
		$sFileSizeSum = $oServiceFile->getFileSizeSum(true);
		$iAmount = round((100/$iDiskFreeSpace) *  $oServiceFile->getFileSizeSum(), 2);
		
		// load some cool stats.
		$oServiceUser = new Service_User();
		$this->view->iUserCount = count($oServiceUser->getAll());
		
		$this->view->iFileCount = $oServiceFile->countRows();
		
		$oServiceFolder = new Service_Folder();
		$this->view->iFolderCount = $oServiceFolder->countRows();
		
		$this->view->sDiskFreeSpace = $sDiskFreeSpace;
		$this->view->sFileSizeSum = $sFileSizeSum;
		$this->view->iAmount = $iAmount;
	}
}