<?php

class Service_File extends Service_Structure
{
	const MIME_TYPE_IMAGE = 'image/jpeg';
	
	protected $oModelFiles;
	
	/**
     * Acceptable prefices of SI
     * @var array 
     */
    protected static $_prefixes = array('', 'k', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y');
    
	public function __construct() 
	{
		$this->_oModelFiles = new Application_Model_Files();
	}
	
	/**
	 * Count all files.
	 * 
	 * @return int count
	 */
	public function countRows()
	{
	    return (int) $this->_oModelFiles->getAdapter()->fetchOne(
	        $this->_oModelFiles->select()->from($this->_oModelFiles, 'COUNT(file_id)')
	    );
	}
	
	/**
	 * Returns one File.
	 * 
	 * @param int $iFileId
	 * @return	Zend_Db_Table_Row_Abstract|null  
	 */
	public function getFile($iFileId)
	{
		return $this->_oModelFiles->fetchRow("file_id = '" . $iFileId . "'");
	}
	
    /**
     * Tranformation to huma-readable format
     * @param  int $size Size in bytes
     * @param  int $precision Presicion of result (default 2)
     * @return string Transformed size
     */
    static public function getFileSize($size, $precision = 2)
    {        
        $result = $size;
        $index = 0; 
        while ($result > 1024 && $index < count(self::$_prefixes)) {
            $result = $result / 1024;
            $index++;
        }
        return sprintf('%1.' . $precision . 'f %sB', $result, self::$_prefixes[$index]);
    }
	
	/**
	 * Get the total size of all files.
	 * 
	 * @param boolean $bFormatted
	 * @return int $iSize
	 */
	public function getFileSizeSum($bFormatted = false, $mParentFolderKey = null)
	{
		if (!is_null($mParentFolderKey))
		{
			$iPrimaryId = $this->getIdToKey($mParentFolderKey, new Application_Model_Folder());
			$oSelect = $this->_oModelFiles->select()
				->from('files', array('sum' => 'SUM(`size`)'))
				->where("folder = '" . $iPrimaryId . "'");
		}
		else 
		{
			$oSelect = $this->_oModelFiles->select()->from('files', array('sum' => 'SUM(`size`)'));
		}
		
		$sStmt = $oSelect->query();
		$aResult = $sStmt->fetchAll();
		$iSize = $aResult[0]['sum'];
		
		if (true == $bFormatted)
		{
			$iSize = $this->getFileSize($iSize);
		}
		
		return $iSize;
	}
	
	/**
	 * Get the total size of all user files.
	 * 
	 * @param int $iUserId
	 * @param boolean $bInMb = true
	 * @param boolean $bFormatted = true
	 * @return mixed $mSize
	 */
	public function getFileSizeSumToUser($iUserId, $bInMb = true, $bFormatted = true)
	{
		$oSelect = $this->_oModelFiles->select()
			->from('files', array('sum' => 'SUM(`size`)'))
			->where("user_id = '" . $iUserId . "'");
			
		$sStmt = $oSelect->query();
		$aResult = $sStmt->fetchAll();
		$mSize = $aResult[0]['sum'];
		
      	if (true === $bInMb)
		{
			$sSize = number_format(($mSize / pow(2,20)), 2) . " MB";
      		return $sSize;
		}
		
		if (true == $bFormatted)
		{
			$mSize = $this->getFileSize($mSize);
		}
		
		return $mSize;
	}
	
	/**
	 * Get folders from directory.
	 * 
	 * @param mixed $mParentFolder
	 * @param mixed $mUserId
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function getFilesFromDirectory($mParentFolderKey = 0, $mUserId = null) 
	{
		$oModelFolder = new Application_Model_Folder();
		if ($mParentFolderKey)
		{
			$iPrimaryId = $this->getIdToKey($mParentFolderKey, $oModelFolder);
		} 
		else
		{
			$iPrimaryId = 0;
		}
		
		$aWhere = array();
		$aWhere[] = "folder = '" . $iPrimaryId . "'";
		
		if (!is_null($mUserId))
		{
			$aWhere[] = "user_id = '" . $mUserId . "'";
		}
		
		return Zend_Paginator::factory($this->_oModelFiles->fetchAll($aWhere, 'name ASC'));

		return $this->_oModelFiles->fetchAll($aWhere, 'name ASC');
	}
	
	/**
	 * Increase the download counter.
	 * 
	 * @param int $iFileId
	 */
	public function increaseDownloadCounter($iFileId)
	{
		$oFile = $this->getFile($iFileId);
		$oFile->downloads++;
		$oFile->save();
	}
	
	/**
	 * Upload a new file.
	 * 
	 * @param array $aData
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function newFile($aData)
	{
		$aData[$this->_oModelFiles->getForeignKey()] =  $this->createUniqueKey($this->_oModelFiles);
		
		return $this->_oModelFiles->insert($aData);
	}
	
	/**
	 * Search files in the db.
	 * 
	 * @param String $sKey
	 * @return Zend_Db_Table_Rowset_Abstract
	 */
	public function searchFiles($sKey)
	{
		$oSelect = $this->_oModelFiles->select()->from('files')->where('name LIKE "%' . $sKey . '%"');
		$oResult = $oSelect->query()->fetchAll();
		return $oResult;
	}
}